aboutsummaryrefslogtreecommitdiff
path: root/MediaBrowser.Model/System
diff options
context:
space:
mode:
authorLuke <luke.pulverenti@gmail.com>2015-10-26 18:50:19 -0400
committerLuke <luke.pulverenti@gmail.com>2015-10-26 18:50:19 -0400
commit35778ebc02e5931142a1fe31a256b7488a07c5c2 (patch)
treeced0290be8820f5e507b51ca4c5165212b1879d1 /MediaBrowser.Model/System
parentc0dc8d055bfd4d2f58591083beb9e9128357aad6 (diff)
parent8d77308593c3b16b733b0109323770d9dfe7e166 (diff)
Merge pull request #1222 from MediaBrowser/dev
3.0.5768.7
Diffstat (limited to 'MediaBrowser.Model/System')
-rw-r--r--MediaBrowser.Model/System/SystemInfo.cs8
1 files changed, 4 insertions, 4 deletions
diff --git a/MediaBrowser.Model/System/SystemInfo.cs b/MediaBrowser.Model/System/SystemInfo.cs
index c8209baa85..e3e8c7be23 100644
--- a/MediaBrowser.Model/System/SystemInfo.cs
+++ b/MediaBrowser.Model/System/SystemInfo.cs
@@ -39,11 +39,11 @@ namespace MediaBrowser.Model.System
public bool HasPendingRestart { get; set; }
/// <summary>
/// Gets or sets a value indicating whether [supports synchronize].
/// </summary>
- /// <value><c>true</c> if [supports synchronize]; otherwise, <c>false</c>.</value>
- public bool SupportsSync { get; set; }
-
+ /// <value><c>true</c> if [supports library monitor]; otherwise, <c>false</c>.</value>
+ public bool SupportsLibraryMonitor { get; set; }
+
/// <summary>
/// Gets or sets a value indicating whether this instance is network deployed.
/// </summary>
@@ -39,11 +39,11 @@ namespace MediaBrowser.Model.System
public bool HasPendingRestart { get; set; }
/// <summary>
- /// Gets or sets a value indicating whether [supports synchronize].
+ /// Gets or sets a value indicating whether [supports library monitor].
/// </summary>